import os, sys
import numpy as np
import warnings

warnings.filterwarnings("ignore")

import matplotlib
matplotlib.use('Agg')
matplotlib.rcParams.update({'font.size': 48})
matplotlib.rcParams['contour.negative_linestyle'] = 'solid'
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['text.latex.unicode'] = True
import matplotlib.pyplot as plt
plt.rcParams['xtick.labelsize']=48
plt.rcParams['ytick.labelsize']=48
from matplotlib.pyplot import cm

configDirectory = "/home/michael.coughlin/gwemopt/config"

events = ["S200105ae","S200213t","S200115j"]
gpstimes = [1262276684.0572,1265602259.327981,1263122607.742047]
skymaps = ["/home/michael.coughlin/gwemopt/data/S200105ae/LALInference.fits.gz","/home/michael.coughlin/gwemopt/data/S200213t/bayestar.fits.gz","/home/michael.coughlin/gwemopt/data/S200115j/LALInference.fits.gz"]

events = ["S200105ae","S200213t"]
gpstimes = [1262276684.0572,1265602259.327981]
skymaps = ["/home/michael.coughlin/gwemopt/data/S200105ae/LALInference.fits.gz","/home/michael.coughlin/gwemopt/data/S200213t/LALInference.fits.gz"]

lightcurveFiles = ["/home/michael.coughlin/gwemopt/lightcurves/Bulla_mejdyn0.005_mejwind0.050_phi45_45.6.dat","/home/michael.coughlin/gwemopt/lightcurves/Bulla_mejdyn0.005_mejwind0.010_phi45_45.6.dat","Tophat","Tophat"]
modelTypes = ["file","file","Tophat","Tophat"]
mags = [-16.0,-16.0,-16.0,-16.0]
dmags = [0.0,0.0,0.0,0.5]
exposuretimes = np.arange(30,630,30)

baseplotDir = "/home/michael.coughlin/gwemopt/output/efficiency"
condorDir = "/home/michael.coughlin/gwemopt/condor"

logDir = os.path.join(condorDir,'logs')
if not os.path.isdir(logDir):
    os.makedirs(logDir)

job_number = 0

fid = open(os.path.join(condorDir,'condor.dag'),'w')
fid2 = open(os.path.join(condorDir,'condor.sh'),'w')

for event,skymap,gpstime in zip(events,skymaps,gpstimes):
    for modelType,lightcurveFile,mag,dmag in zip(modelTypes,lightcurveFiles,mags,dmags):
        for exposuretime in exposuretimes:
            if modelType == "Tophat":
                lcurve = "%.1f_%.1f"%(mag,dmag)
            else:
                lcurve = lightcurveFile.split("/")[-1].replace(".dat","")
            outputDir = os.path.join(baseplotDir,event,lcurve,"%d"%(exposuretime))
            #fid2.write('/home/michael.coughlin/gwemopt/bin/gwemopt_run --doRASlices --Tobs 0.0,3.0 --telescope ZTF --doSchedule --doSkymap --doPlots --skymap %s --gpstime %.2f --doTiles --doSingleExposure --filters g,r,g,r,g,r --powerlaw_cl 0.9 --doAlternatingFilters --doEfficiency --do3D --modelType %s --mag %.1f --dmag %.1f --lightcurveFiles %s -o %s --exposuretimes %d,%d --doUsePrimary -c %s\n' % (skymap,gpstime,modelType,mag,dmag,lightcurveFile,outputDir,exposuretime,exposuretime,configDirectory))

            efficiency_file = os.path.join(outputDir,'efficiency.txt')
            if not os.path.isfile(efficiency_file):
                fid2.write('/home/michael.coughlin/gwemopt/bin/gwemopt_run --Ninj 10000 --mindiff 10800 --Tobs 0.0,3.0 --telescope ZTF --doSchedule --doSkymap --doPlots --skymap %s --gpstime %.2f --doTiles --doSingleExposure --filters g,r,g,r --powerlaw_cl 0.9 --doEfficiency --do3D --modelType %s --mag %.1f --dmag %.1f --lightcurveFiles %s -o %s --exposuretimes %d,%d,%d,%d --doUsePrimary -c %s\n' % (skymap,gpstime,modelType,mag,dmag,lightcurveFile,outputDir,exposuretime,exposuretime,exposuretime,exposuretime,configDirectory))

                fid.write('JOB %d condor.sub\n'%(job_number))
                fid.write('RETRY %d 3\n'%(job_number))
                fid.write('VARS %d jobNumber="%d" skymap="%s" gpstime="%.2f" lightcurveFile="%s" outputDir="%s" modelType="%s" mag="%.1f" dmag="%.1f" exposuretimes="%d,%d,%d,%d"\n'%(job_number,job_number,skymap,gpstime,lightcurveFile,outputDir,modelType,mag,dmag,exposuretime,exposuretime,exposuretime,exposuretime))
                #fid.write('VARS %d jobNumber="%d" skymap="%s" gpstime="%.2f" lightcurveFile="%s" outputDir="%s" modelType="%s" mag="%.1f" dmag="%.1f" exposuretimes="%d"\n'%(job_number,job_number,skymap,gpstime,lightcurveFile,outputDir,modelType,mag,dmag,exposuretime))
                fid.write('\n\n')
                job_number = job_number + 1
fid.close()
fid2.close()

fid = open(os.path.join(condorDir,'condor.sub'),'w')
fid.write('executable = /home/michael.coughlin/gwemopt/bin/gwemopt_run\n')
fid.write('output = logs/out.$(jobNumber)\n');
fid.write('error = logs/err.$(jobNumber)\n');
fid.write('arguments = --Ninj 10000 --mindiff 10800 --Tobs 0.0,3.0 --telescope ZTF --doSchedule --doSkymap --doPlots --skymap $(skymap) --gpstime $(gpstime) --doTiles --doSingleExposure --filters g,r,g,r --powerlaw_cl 0.9 --doEfficiency --do3D --modelType $(modelType) --mag $(mag) --dmag $(dmag) --lightcurveFiles $(lightcurveFile) -o $(outputDir) --exposuretimes $(exposuretimes) --doUsePrimary -c %s\n' % (configDirectory))
#fid.write('arguments = --doRASlices --telescope ZTF --doSchedule --doSkymap --doPlots --skymap $(skymap) --gpstime $(gpstime) --doTiles --doSingleExposure --filters g,r --powerlaw_cl 0.9 --doAlternatingFilters --doEfficiency --do3D --modelType $(modelType) --mag $(mag) --dmag $(dmag) --lightcurveFiles $(lightcurveFile) -o $(outputDir) --exposuretimes $(exposuretimes) --doUsePrimary -c %s\n' % (configDirectory)) 
#fid.write('arguments = --telescope ZTF --doSchedule --doSkymap --doPlots --skymap $(skymap) --gpstime $(gpstime) --doTiles --doSingleExposure --filters g --powerlaw_cl 0.9 --doAlternatingFilters --doEfficiency --do3D --modelType $(modelType) --mag $(mag) --dmag $(dmag) --lightcurveFiles $(lightcurveFile) -o $(outputDir) --exposuretimes $(exposuretimes) --doUsePrimary -c %s\n' % (configDirectory)) 
fid.write('requirements = OpSys == "LINUX"\n');
fid.write('request_memory = 8000\n');
fid.write('request_cpus = 1\n');
fid.write('accounting_group = ligo.dev.o2.burst.allsky.stamp\n');
fid.write('notification = never\n');
fid.write('getenv = true\n');
fid.write('log = /usr1/michael.coughlin/gwemopt_efficiency.log\n')
fid.write('+MaxHours = 24\n');
fid.write('universe = vanilla\n');
fid.write('queue 1\n');
fid.close()




import time
import copy

import mocpy
from mocpy import MOC
from astropy.table import Table
import healpy as hp
import numpy as np
from regions import Regions, CircleSkyRegion, RectangleSkyRegion, PolygonSkyRegion

import ligo.segments as segments
from ligo.skymap.bayestar import rasterize

import gwemopt.tiles
from gwemopt.tiles import powerlaw_tiles_struct, absmag_tiles_struct, get_rectangle, angular_distance

def create_galaxy_from_skyportal(params, map_struct, catalog_struct, regions=None):
    nside = params["nside"]

    tile_structs = {}
    for telescope in params["telescopes"]:

        config_struct = params["config"][telescope]
        if type(regions[0]) == RectangleSkyRegion:
             config_struct["FOV_type"] = "square"
             config_struct["FOV"] = np.max([regions[0].width.value, regions[0].height.value])
        elif type(regions[0]) == CircleSkyRegion:   
             config_struct["FOV_type"] = "circle"
             config_struct["FOV"] = regions[0].radius.value
        elif type(regions[0]) == PolygonSkyRegion:
             ra = np.array([regions[0].vertices.ra for reg in regions])
             dec = np.array([regions[0].vertices.dec for reg in regions])
             min_ra, max_ra = np.min(ra), np.max(ra)
             min_dec, max_dec = np.min(dec), np.max(dec)
             config_struct["FOV_type"] = "square"
             config_struct["FOV"] = np.max([max_ra-min_ra, max_dec-min_dec])

        # Combine in a single pointing, galaxies that are distant by
        # less than FoV * params['galaxies_FoV_sep']
        # Take galaxy with highest proba at the center of new pointing
        FoV = params["config"][telescope]['FOV'] * params['galaxies_FoV_sep']
        if 'FOV_center' in params["config"][telescope]:
            FoV_center = params["config"][telescope]['FOV_center'] * params['galaxies_FoV_sep']
        else:
            FoV_center = params["config"][telescope]['FOV'] * params['galaxies_FoV_sep']

        new_ra = []
        new_dec = []
        new_Sloc = []
        new_Smass = []
        new_S = []
        galaxies = []
        idxRem = np.arange(len(catalog_struct["ra"])).astype(int)

        while len(idxRem) > 0:
            ii = idxRem[0]
            ra, dec, Sloc, S, Smass = catalog_struct["ra"][ii], catalog_struct["dec"][ii], catalog_struct["Sloc"][ii], catalog_struct["S"][ii], catalog_struct["Smass"][ii]

            if config_struct["FOV_type"] == "square":
                decCorners = (dec - FoV, dec + FoV)
                # assume small enough to use average dec for corners
                raCorners = (ra - FoV/np.cos(np.deg2rad(dec)) , ra + FoV / np.cos(np.deg2rad(dec)))
                idx1 = np.where((catalog_struct["ra"][idxRem]>=raCorners[0]) & (catalog_struct["ra"][idxRem]<=raCorners[1]))[0]
                idx2 = np.where((catalog_struct["dec"][idxRem]>=decCorners[0]) & (catalog_struct["dec"][idxRem]<=decCorners[1]))[0]
                mask = np.intersect1d(idx1,idx2)

                if len(mask) > 1:
                    ra_center, dec_center = get_rectangle(catalog_struct["ra"][idxRem][mask], catalog_struct["dec"][idxRem][mask], FoV/np.cos(np.deg2rad(dec)), FoV)

                    decCorners = (dec_center - FoV/2.0, dec_center + FoV/2.0)
                    raCorners = (ra_center - FoV/(2.0*np.cos(np.deg2rad(dec))) , ra_center + FoV/(2.0*np.cos(np.deg2rad(dec))))
                    idx1 = np.where((catalog_struct["ra"][idxRem]>=raCorners[0]) & (catalog_struct["ra"][idxRem]<=raCorners[1]))[0]
                    idx2 = np.where((catalog_struct["dec"][idxRem]>=decCorners[0]) & (catalog_struct["dec"][idxRem]<=decCorners[1]))[0]
                    mask2 = np.intersect1d(idx1,idx2)

                    decCorners = (dec_center - FoV_center/2.0, dec_center + FoV_center/2.0)
                    raCorners = (ra_center - FoV_center/(2.0*np.cos(np.deg2rad(dec))) , ra_center + FoV_center/(2.0*np.cos(np.deg2rad(dec))))
                    idx1 = np.where((catalog_struct["ra"][idxRem]>=raCorners[0]) & (catalog_struct["ra"][idxRem]<=raCorners[1]))[0]
                    idx2 = np.where((catalog_struct["dec"][idxRem]>=decCorners[0]) & (catalog_struct["dec"][idxRem]<=decCorners[1]))[0]
                    mask3 = np.intersect1d(idx1,idx2)

                    # did the optimization help?
                    if (len(mask2) > 2) and (len(mask3) > 0):
                        mask = mask2
                else:
                    ra_center, dec_center = np.mean(catalog_struct["ra"][idxRem][mask]), np.mean(catalog_struct["dec"][idxRem][mask])

            elif config_struct["FOV_type"] == "circle":
                dist = angular_distance(ra, dec,
                                        catalog_struct["ra"][idxRem],
                                        catalog_struct["dec"][idxRem])
                mask = np.where((2 * FoV) >= dist)[0]
                if len(mask) > 1:
                    ra_center, dec_center = get_rectangle(catalog_struct["ra"][idxRem][mask], catalog_struct["dec"][idxRem][mask], (FoV/np.sqrt(2))/np.cos(np.deg2rad(dec)), FoV/np.sqrt(2))

                    dist = angular_distance(ra_center, dec_center,
                                            catalog_struct["ra"][idxRem],
                                            catalog_struct["dec"][idxRem])
                    mask2 = np.where(FoV >= dist)[0]
                    # did the optimization help?
                    if len(mask2) > 2:
                        mask = mask2
                else:
                    ra_center, dec_center = np.mean(catalog_struct["ra"][idxRem][mask]), np.mean(catalog_struct["dec"][idxRem][mask])

            new_ra.append(ra_center)
            new_dec.append(dec_center)
            new_Sloc.append(np.sum(catalog_struct["Sloc"][idxRem][mask]))
            new_S.append(np.sum(catalog_struct["S"][idxRem][mask]))
            new_Smass.append(np.sum(catalog_struct["Smass"][idxRem][mask]))
            galaxies.append(idxRem[mask])

            idxRem = np.setdiff1d(idxRem, idxRem[mask])

        # redefine catalog_struct
        catalog_struct_new = {}
        catalog_struct_new["ra"] = new_ra
        catalog_struct_new["dec"] = new_dec
        catalog_struct_new["Sloc"] = new_Sloc
        catalog_struct_new["S"] = new_S
        catalog_struct_new["Smass"] = new_Smass
        catalog_struct_new["galaxies"] = galaxies

        moc_struct = {}
        cnt = 0
        for ra, dec, Sloc, S, Smass, galaxies in zip(catalog_struct_new["ra"], catalog_struct_new["dec"], catalog_struct_new["Sloc"], catalog_struct_new["S"], catalog_struct_new["Smass"], catalog_struct_new["galaxies"]):
            moc_struct[int(cnt)] = gwemopt.moc.Fov2Moc(params, config_struct, telescope, ra, dec, nside)
            moc_struct[int(cnt)]["galaxies"] = galaxies
            cnt = cnt + 1
   
        if params["timeallocationType"] == "absmag":
            tile_struct = absmag_tiles_struct(params, config_struct, telescope, map_struct, moc_struct)
        elif params["timeallocationType"] == "powerlaw":
            tile_struct = powerlaw_tiles_struct(params, config_struct, telescope, map_struct, moc_struct, catalog_struct=catalog_struct)

        tile_struct = gwemopt.segments.get_segments_tiles(params, config_struct, tile_struct)

        cnt = 0
        for ra, dec, Sloc, S, Smass,  galaxies in zip(catalog_struct_new["ra"], catalog_struct_new["dec"], catalog_struct_new["Sloc"], catalog_struct_new["S"],catalog_struct_new["Smass"], catalog_struct_new["galaxies"]):
            if params["galaxy_grade"] == "Sloc":
                tile_struct[cnt]['prob'] = Sloc
            elif params["galaxy_grade"] == "S":
                tile_struct[cnt]['prob'] = S
            elif params["galaxy_grade"] == "Smass":
                tile_struct[cnt]['prob'] = Smass

            tile_struct[cnt]['galaxies'] = galaxies
            if config_struct["FOV_type"] == "square":
                tile_struct[cnt]['area'] = params["config"][telescope]['FOV']**2
            elif config_struct["FOV_type"] == "circle":
                tile_struct[cnt]['area'] = 4*np.pi*params["config"][telescope]['FOV']**2
            cnt = cnt + 1

        tile_structs[telescope] = tile_struct

    return tile_structs


def create_moc_from_skyportal(params, map_struct=None, field_ids=None):

    nside = params["nside"]
    npix = hp.nside2npix(nside)

    if params["doMinimalTiling"]:
        prob = map_struct["prob"]

        n, cl, dist_exp = params["powerlaw_n"], params["powerlaw_cl"], params["powerlaw_dist_exp"]
        prob_scaled = copy.deepcopy(prob)
        prob_sorted = np.sort(prob_scaled)[::-1]
        prob_indexes = np.argsort(prob_scaled)[::-1]
        prob_cumsum = np.cumsum(prob_sorted)
        index = np.argmin(np.abs(prob_cumsum - cl)) + 1
        prob_indexes = prob_indexes[:index+1]

    if "doUsePrimary" in params:
        doUsePrimary = params["doUsePrimary"]
    else:
        doUsePrimary = False

    if "doUseSecondary" in params:
        doUseSecondary = params["doUseSecondary"]
    else:
        doUseSecondary = False

    npix = hp.nside2npix(nside)
    pixarea = hp.nside2pixarea(nside)

    theta, phi = hp.pix2ang(nside, np.arange(npix))
    ra = np.rad2deg(phi)
    dec = np.rad2deg(0.5*np.pi - theta)

    moc_structs = {}
    for telescope in params["telescopes"]:
        config_struct = params["config"][telescope]
        tesselation = config_struct["tesselation"]
        moc_struct = {}

        if params["doParallel"]:
            ipixs = Parallel(n_jobs=params["Ncores"])(delayed(skyportal2Moc)(tess, nside) for tess in tesselation)
        else:
            ipixs = []
            for ii, tess in enumerate(tesselation):
                if field_ids is not None:
                    if tess.field_id not in field_ids[telescope]:
                        ipixs.append([])
                        continue
                ipixs.append(skyportal2FOV(tess, nside))
        for ii, tess in enumerate(tesselation):
            index = tess.field_id

            if (telescope == "ZTF") and doUsePrimary and (index > 880):
                continue
            if (telescope == "ZTF") and doUseSecondary and (index < 1000):
                continue

            ipix = ipixs[ii]
            if len(ipix) == 0: continue

            moc_struct[index] = {}
            moc_struct[index]["ra"] = tess.ra
            moc_struct[index]["dec"] = tess.dec

            moc_struct[index]["ipix"] = ipix
            moc_struct[index]["corners"] = [[np.min(ra[ipix]), np.min(dec[ipix])],
                                            [np.min(ra[ipix]), np.max(dec[ipix])],
                                            [np.max(ra[ipix]), np.max(dec[ipix])],
                                            [np.max(ra[ipix]), np.min(dec[ipix])]]
            moc_struct[index]["patch"] = []
            moc_struct[index]["area"] = len(ipix)*pixarea

        if map_struct is not None:
            ipix_keep = map_struct["ipix_keep"]
        else:
            ipix_keep = []

        if params["doMinimalTiling"]:
            moc_struct_new = copy.copy(moc_struct)
            if params["tilesType"] == "galaxy":
                tile_probs = gwemopt.tiles.compute_tiles_map(params, moc_struct_new, prob, func='center', ipix_keep=ipix_keep)
            else:
                tile_probs = gwemopt.tiles.compute_tiles_map(params, moc_struct_new, prob, func='np.sum(x)', ipix_keep=ipix_keep)

            keys = moc_struct.keys()

            sort_idx = np.argsort(tile_probs)[::-1]
            csm = np.empty(len(tile_probs))
            csm[sort_idx] = np.cumsum(tile_probs[sort_idx])
            ipix_keep = np.where(csm <= cl)[0]

            probs = []
            moc_struct = {}
            cnt = 0
            for ii, key in enumerate(keys):
                if ii in ipix_keep:
                    moc_struct[key] = moc_struct_new[key]
                    cnt = cnt + 1

        moc_structs[telescope] = moc_struct

    return moc_structs


def skyportal2FOV(tess, nside):

    moc = moc_from_tiles([tile.healpix for tile in tess.tiles], 2**29)
    pix_id = moc.degrade_to_order(int(np.log2(nside))).flatten()
    if len(pix_id) > 0:
        ipix = hp.nest2ring(int(nside), pix_id.tolist())
    else:
        ipix = []

    return ipix

def moc_from_tiles(rangeSet, nside):
    depth = int(np.log2(nside))
    segmentlist = segments.segmentlist()
    for x in rangeSet:
        segment = segments.segment(x.lower, x.upper-1)
        segmentlist = segmentlist + segments.segmentlist([segment])
    segmentlist.coalesce()

    MOCstr = f'{depth}/' + ' '.join(map(lambda x: f'{x[0]}-{x[1]}',
                                        segmentlist))
    return MOC.from_string(MOCstr)




import os
import glob
import optparse

import numpy as np
from astropy.time import Time

import matplotlib
font = {'family' : 'normal',
        'weight' : 'normal',
        'size'   : 24}
matplotlib.rc('xtick', labelsize=22)
matplotlib.rc('ytick', labelsize=22)
matplotlib.rc('font', **font)
import matplotlib.pyplot as plt

from matplotlib.colors import LogNorm
from matplotlib.patches import Rectangle

outputDir = '../plots/telescopes/'
if not os.path.isdir(outputDir):
    os.makedirs(outputDir)

color1 = 'cornflowerblue'

filename = "../data/S200213t/telescopes.dat"

teles = [line.rstrip('\n') for line in open(filename,'r')]

diffs = [[0.88,0.95], 
         [0.95,0.95],
         [0.80,1.03], 
         [0.95,0.95],
         [1.2,0.9], 
         [0.98, 1.02],
         [0.95, 0.92]]

diffsl =[[-0.09, -0.02],
         [-0.05, -0.01],
         [-0.5, 0.01],
         [0.01, 0.0], 
         [0.03, 0.01],
         [0.05, 0.01]]

plotName = os.path.join(outputDir,'S200213t_performance.pdf')
fig = plt.figure(figsize=(8,6))
ax = plt.subplot(111)

absmag = -16.0
event_mu, event_std = 224, 90
event_mag = 5.0*(np.log10(event_mu*1e6)-1.0) + absmag
event_mag_lower = 5.0*(np.log10((event_mu-event_std)*1e6)-1.0) + absmag
event_mag_upper = 5.0*(np.log10((event_mu+event_std)*1e6)-1.0) + absmag
event_mag_diff = event_mag_upper-event_mag_lower

plt.plot([-5,100], [event_mag,event_mag], alpha=1.0, color='g')
rect1 = Rectangle((-5, event_mag_lower), 105, event_mag_diff, alpha=0.3, color='g')
ax.add_patch(rect1)

plt.xlabel('Probability Enclosed')
plt.ylabel('Limiting Magnitude')
for tele, diff, diffl in zip(teles,diffs,diffsl):
    telesplit = tele.split(" ")
    tel, limmag, coverage = telesplit[0], float(telesplit[1]), float(telesplit[2])
    #plt.text(model[3], model[1], model[0])
    plt.plot(coverage, limmag, marker='o', markerfacecolor=color1,
                markeredgecolor='black', markersize=25)

    diffx, diffy = diff
    x, y = coverage, limmag
    difflx, diffly = diffl

    x1text = x*diffx*(1.+difflx)
    y1text = y*diffy*(1.+diffly)

    x1arrow = x*diffx*1.01
    y1arrow = y*diffy*1.01

    plt.text(x1text, y1text, tel)
    plt.annotate('', xy=(x,y), xytext=(x1arrow,y1arrow),
                 arrowprops=dict(facecolor='black', arrowstyle='->'),
                 )

plt.xlim([-5,100])
plt.ylim([15.5,22.5])
#plt.gca().invert_yaxis()
plt.savefig(plotName,bbox_inches='tight')
plt.close()





import os, sys
import numpy as np
import warnings

warnings.filterwarnings("ignore")

import matplotlib
matplotlib.use('Agg')
matplotlib.rcParams.update({'font.size': 24})
matplotlib.rcParams['contour.negative_linestyle'] = 'solid'
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['text.latex.unicode'] = True
import matplotlib.pyplot as plt
plt.rcParams['xtick.labelsize']=24
plt.rcParams['ytick.labelsize']=24
from matplotlib.pyplot import cm

from matplotlib.patches import Rectangle

configDirectory = "/home/michael.coughlin/gwemopt/config"


events = ["S200105ae","S200213t","S200115j"]
gpstimes = [1262276684.0572,1265602259.327981,1263122607.742047]
skymaps = ["/home/michael.coughlin/gwemopt/data/S200105ae/LALInference.fits.gz","/home/michael.coughlin/gwemopt/data/S200213t/LALInference.fits.gz","/home/michael.coughlin/gwemopt/data/S200115j/LALInference.fits.gz"]

events = ["S200105ae","S200213t"]
gpstimes = [1262276684.0572,1265602259.327981]
skymaps = ["/home/michael.coughlin/gwemopt/data/S200105ae/LALInference.fits.gz","/home/michael.coughlin/gwemopt/data/S200213t/LALInference.fits.gz"]

lightcurveFiles = ["/home/michael.coughlin/gwemopt/lightcurves/Bulla_mejdyn0.005_mejwind0.050_phi45_45.6.dat","/home/michael.coughlin/gwemopt/lightcurves/Bulla_mejdyn0.005_mejwind0.010_phi45_45.6.dat","Tophat","Tophat"]
lightcurveLabels = ['KN: 0.005 $M_\odot$, 0.05 $M_\odot$', 
                    'KN: 0.005 $M_\odot$, 0.01 $M_\odot$',
                    'Tophat: -16 mag, 0 mag/day',
                    'Tophat: -16 mag, 0.5 mag/day']

modelTypes = ["file","file","Tophat","Tophat"]
mags = [-16.0,-16.0,-16.0,-16.0]
dmags = [0.0,0.0,0.0,0.5]
exposuretimes = np.arange(30,630,30)

baseplotDir = "/home/michael.coughlin/gwemopt/output/efficiency"
condorDir = "/home/michael.coughlin/gwemopt/condor"

data = {}

for event,skymap,gpstime in zip(events,skymaps,gpstimes):
    data[event] = {}
    for modelType,lightcurveFile,mag,dmag,lightcurveLabel in zip(modelTypes,lightcurveFiles,mags,dmags,lightcurveLabels):
        for exposuretime in exposuretimes:
            if modelType == "Tophat":
                lcurve = "%.1f_%.1f"%(mag,dmag)
            else:
                lcurve = lightcurveFile.split("/")[-1].replace(".dat","")
            outputDir = os.path.join(baseplotDir,event,lcurve,"%d"%(exposuretime))
            if not lcurve in data[event]:
                data[event][lcurve] = {}
                data[event][lcurve]["label"] = lightcurveLabel
                data[event][lcurve]["ntiles"] = []
                data[event][lcurve]["probs"] = []
                data[event][lcurve]["data"] = []

            efficiency_file = os.path.join(outputDir,'efficiency.txt')
            if os.path.isfile(efficiency_file):
                lines = [line.rstrip('\n') for line in open(efficiency_file,'r')]
                line = lines[1].split("\t")
                data[event][lcurve]["data"].append([exposuretime,float(line[4])])

            schedule_file = os.path.join(outputDir,'coverage_ZTF.dat')
            if os.path.isfile(schedule_file):
                data_out = np.atleast_2d(np.loadtxt(schedule_file))
                if data_out.size == 0: continue
                data[event][lcurve]["ntiles"].append([exposuretime,len(data_out[:,0])])
                data[event][lcurve]["probs"].append([exposuretime,np.sum(data_out[:,1])])
        data[event][lcurve]["ntiles"] = np.array(data[event][lcurve]["ntiles"])
        data[event][lcurve]["probs"] = np.array(data[event][lcurve]["probs"])
        data[event][lcurve]["data"] = np.array(data[event][lcurve]["data"])

color2 = 'coral'
color1 = 'cornflowerblue'
color3 = 'darkgreen'
color4 = 'darkmagenta'

colors = [color1,color2,color3,color4]
linestyles = ['-', '-.', ':','--']

for event,skymap,gpstime in zip(events,skymaps,gpstimes):
    outputDir = os.path.join(baseplotDir,event)
    plt.figure(figsize=(10,6))
    ax1 = plt.gca()
    ax2 = ax1.twinx()
    for ii, lcurve in enumerate(data[event].keys()):
        if data[event][lcurve]["data"].size == 0: continue
        ax1.step(data[event][lcurve]["data"][:,0], data[event][lcurve]["data"][:,1], linestyles[ii], where='mid', label=data[event][lcurve]["label"], color=colors[ii])
    ax1.legend(loc=9,ncol=2,labelspacing=0.3,columnspacing=0.3,handlelength=2,prop={'size':18})
    for lcurve in data[event].keys():
        ax2.step(data[event][lcurve]["ntiles"][:,0], data[event][lcurve]["probs"][:,1], '-', where='mid',label=data[event][lcurve]["label"], color='k')

    ax1.set_xlabel('Exposure time [s]')
    ax1.set_ylabel('Detection Efficiency')
    ax2.set_ylabel('Integrated Probability')

    ax1.plot([30,30],[0,1],'k--')
    rect1 = Rectangle((120, 0), 180, 1, alpha=0.3, color='g')
    ax1.add_patch(rect1)

    plt.text(40, 1.05, "Survey")
    plt.annotate('', xy=(0.02, 1.03), xytext=(0.17,1.03), xycoords='axes fraction',
                 arrowprops=dict(facecolor='black', arrowstyle='->'),
                 )

    plt.text(185, 1.05, "ToO")
    plt.annotate('', xy=(0.17, 1.03), xytext=(0.5,1.03), xycoords='axes fraction',
                 arrowprops=dict(facecolor='black', arrowstyle='<->'),
                 )

    ax1.set_xlim([15,600])
    ax1.set_ylim([0,1.0])
    ax2.set_ylim([0,1.0])

    plotName = os.path.join(outputDir,'efficiency.pdf')
    plt.savefig(plotName,bbox_inches='tight')
    plt.close()

    plt.figure(figsize=(10,6))
    for lcurve in data[event].keys():
        if data[event][lcurve]["ntiles"].size == 0: continue
        plt.step(data[event][lcurve]["ntiles"][:,0], data[event][lcurve]["ntiles"][:,1], '.-', where='mid',label=data[event][lcurve]["label"])
    plt.legend(loc=3)
    plotName = os.path.join(outputDir,'ntiles.pdf')
    plt.savefig(plotName,bbox_inches='tight')
    plt.close()

    plt.figure(figsize=(10,6))
    for lcurve in data[event].keys():
        if data[event][lcurve]["probs"].size == 0: continue
        plt.step(data[event][lcurve]["probs"][:,0], data[event][lcurve]["probs"][:,1], 'x', label=data[event][lcurve]["label"])
    plt.legend(loc=3)
    plotName = os.path.join(outputDir,'probs.pdf')
    plt.savefig(plotName,bbox_inches='tight')
    plt.close()
